@@ -176,7 +176,7 @@ fallback_shape (PangoEngineShape *engine,
 		PangoFont        *font,
 		const char       *text,
 		gint              length,
-		PangoAnalysis    *analysis,
+		const PangoAnalysis *analysis,
 		PangoGlyphString *glyphs)
 {
   PangoFcFont *fc_font = PANGO_FC_FONT (font);
@@ -209,14 +209,14 @@ fallback_shape (PangoEngineShape *engine,
 
       if (pango_is_zero_width (wc))
 	{
-	  set_glyph (font, glyphs, i, p - text, 0);
+	  set_glyph (font, glyphs, i, p - text, PANGO_GLYPH_EMPTY);
 	}
       else
 	{
 	  index = pango_fc_font_get_glyph (fc_font, wc);
 
 	  if (!index)
-	    index = pango_fc_font_get_unknown_glyph (fc_font, wc);
+	    index = PANGO_GET_UNKNOWN_GLYPH ( wc);
 
 	  set_glyph (font, glyphs, i, p - text, index);
 	}
@@ -253,19 +253,19 @@ arabic_engine_shape (PangoEngineShape *engine,
 		     PangoFont        *font,
 		     const char       *text,
 		     gint              length,
-		     PangoAnalysis    *analysis,
+		     const PangoAnalysis *analysis,
 		     PangoGlyphString *glyphs)
 {
-  glong n_chars;
-  gunichar *wcs;
-  int i;
-  const char *p;
-  gulong *properties = NULL;
+  PangoFcFont *fc_font;
   FT_Face face;
   PangoOTRuleset *ruleset;
   PangoOTBuffer *buffer;
-  PangoFcFont *fc_font;
+  gulong *properties = NULL;
+  glong n_chars;
+  gunichar *wcs;
+  const char *p;
   int cluster = 0;
+  int i;
 
   g_return_if_fail (font != NULL);
   g_return_if_fail (text != NULL);
@@ -273,9 +273,9 @@ arabic_engine_shape (PangoEngineShape *engine,
   g_return_if_fail (analysis != NULL);
 
   fc_font = PANGO_FC_FONT (font);
-
   face = pango_fc_font_lock_face (fc_font);
-  g_assert (face);
+  if (!face)
+    return;
 
   ruleset = get_ruleset (face);
   if (!ruleset)
@@ -318,7 +318,7 @@ arabic_engine_shape (PangoEngineShape *engine,
 
       if (pango_is_zero_width (wc))	/* Zero-width characters */
 	{
-	  pango_ot_buffer_add_glyph (buffer, 0, properties[i], p - text);
+	  pango_ot_buffer_add_glyph (buffer, PANGO_GLYPH_EMPTY, properties[i], p - text);
 	}
       else
 	{
@@ -336,7 +336,7 @@ arabic_engine_shape (PangoEngineShape *engine,
 
 	  if (!index)
 	    {
-	      pango_ot_buffer_add_glyph (buffer, pango_fc_font_get_unknown_glyph (fc_font, wc),
+	      pango_ot_buffer_add_glyph (buffer, PANGO_GET_UNKNOWN_GLYPH ( wc),
 					 properties[i], p - text);
 	    }
 	  else
